@@ -18,8 +18,9 @@ Usage::
     list_workspaces_paginator: ListWorkspacesPaginator = client.get_paginator("list_workspaces")
     ```
 """
-from typing import Iterator
+from typing import Generic, Iterator, TypeVar
 
+from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .type_defs import ListWorkspacesResponseTypeDef, PaginatorConfigTypeDef
@@ -27,16 +28,26 @@ from .type_defs import ListWorkspacesResponseTypeDef, PaginatorConfigTypeDef
 __all__ = ("ListWorkspacesPaginator",)
 
 
+_ItemTypeDef = TypeVar("_ItemTypeDef")
+
+
+class _PageIterator(Generic[_ItemTypeDef], PageIterator):
+    def __iter__(self) -> Iterator[_ItemTypeDef]:
+        """
+        Proxy method to specify iterator item type.
+        """
+
+
 class ListWorkspacesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/amp.html#PrometheusService.Paginator.ListWorkspaces)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/amp.html#PrometheusService.Paginator.ListWorkspaces)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amp/paginators.html#listworkspacespaginator)
     """
 
     def paginate(
         self, *, alias: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListWorkspacesResponseTypeDef]:
+    ) -> _PageIterator[ListWorkspacesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/amp.html#PrometheusService.Paginator.ListWorkspaces.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/amp.html#PrometheusService.Paginator.ListWorkspaces.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amp/paginators.html#listworkspacespaginator)
         """
