@@ -29,10 +29,14 @@ __all__ = (
     "DeleteWorkspaceRequestRequestTypeDef",
     "DescribeWorkspaceRequestRequestTypeDef",
     "DescribeWorkspaceResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "ListTagsForResourceResponseTypeDef",
     "ListWorkspacesRequestRequestTypeDef",
     "ListWorkspacesResponseTypeDef",
     "PaginatorConfigTypeDef",
     "ResponseMetadataTypeDef",
+    "TagResourceRequestRequestTypeDef",
+    "UntagResourceRequestRequestTypeDef",
     "UpdateWorkspaceAliasRequestRequestTypeDef",
     "WorkspaceDescriptionTypeDef",
     "WorkspaceStatusTypeDef",
@@ -44,6 +48,7 @@ CreateWorkspaceRequestRequestTypeDef = TypedDict(
     {
         "alias": str,
         "clientToken": str,
+        "tags": Dict[str, str],
     },
     total=False,
 )
@@ -53,6 +58,7 @@ CreateWorkspaceResponseTypeDef = TypedDict(
     {
         "arn": str,
         "status": "WorkspaceStatusTypeDef",
+        "tags": Dict[str, str],
         "workspaceId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
@@ -94,6 +100,21 @@ DescribeWorkspaceResponseTypeDef = TypedDict(
     },
 )
 
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
+    {
+        "resourceArn": str,
+    },
+)
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ListWorkspacesRequestRequestTypeDef = TypedDict(
     "ListWorkspacesRequestRequestTypeDef",
     {
@@ -134,6 +155,22 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "resourceArn": str,
+        "tags": Dict[str, str],
+    },
+)
+
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
+    {
+        "resourceArn": str,
+        "tagKeys": List[str],
+    },
+)
+
 _RequiredUpdateWorkspaceAliasRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateWorkspaceAliasRequestRequestTypeDef",
     {
@@ -171,6 +208,7 @@ _OptionalWorkspaceDescriptionTypeDef = TypedDict(
     {
         "alias": str,
         "prometheusEndpoint": str,
+        "tags": Dict[str, str],
     },
     total=False,
 )
@@ -202,6 +240,7 @@ _OptionalWorkspaceSummaryTypeDef = TypedDict(
     "_OptionalWorkspaceSummaryTypeDef",
     {
         "alias": str,
+        "tags": Dict[str, str],
     },
     total=False,
 )
